function [L, lambda, h] = Borkowski(x_e_eb, y_e_eb, z_e_eb)
%Mtode per passar de coordenades ECEF (cartesianes) a coordenades NED
%(pseudoesfriques). S'anomena Borkowski.
%Input:
%       x_e_eb, y_e_eb, z_e_eb: coordenades ECEF. (m)
%Outputs:
%       L: latitud (rad).
%       lambda: longitud (rad)
%       h: altura sobre el nivell del mar (m).
    
    Ro = 6378137;
    e = 0.08181919;
    
    lambda = atan2(y_e_eb, x_e_eb);
    
    B = sqrt(x_e_eb^2 + y_e_eb^2);
    
    E = (sqrt(1 - e^2)*abs(z_e_eb) - e^2*Ro)/B;
    
    F = (sqrt(1 - e^2)*abs(z_e_eb) + e^2*Ro)/B;
    
    P = 4/3*(E*F + 1);
    
    Q = 2*(E^2 - F^2);
    
    D = P^3 + Q^2;
    
    V = (D^(1/2) - Q)^(1/3) - (D^(1/2) + Q)^(1/3);
    
    G = 1/2*(sqrt(E^2 + V) + E);
    
    T = sqrt(G^2 + (F - V*G)/(2*G - E)) - G;
    
    L = sign(z_e_eb)*atan((1 - T^2)/(2*T*sqrt(1 - e^2)));
    
    h = (B - Ro*T)*cos(L) + (z_e_eb - sign(z_e_eb)*Ro*sqrt(1-e^2))*sin(L);

end

