function [ R_e_eb, V_e_eb, C_ecef_b] = equacionsNavegacioECEF(t, R_e_eb_vella, V_e_eb_vella, C_ecef_b_vella, F_b_ib, W_b_ib )
%Cont les equacions navegaci per trobar posici, velocitat i orientaci
%respecte el sistema ECEF.
%Inputs:
%       t: temps de durada d'una iteraci (s)
%       R_e_eb_vella: posici resultant de la iteraci anterior (m)
%       V_e_eb_vella: velocitat resultant de la iteraci anterior (m/s)
%       C_ecef_b_vella: matriu de rotaci resultant de la iteraci 
%       anterior (rad)
%       F_b_ib: lectura dels accelermetres per fer els nous clculs.
%       W_b_ib: lectura dels giroscopis.
%Outputs:
%       R_e_eb: nova posici resultant dels clculs (m)
%       V_e_eb: nova velocitat resultant dels clculs (m/s)
%       C_e_eb: nova matriu de rotaci.
        
        w_ie = 7.292115e-5;
        wx_b_ib = W_b_ib(1);
        wy_b_ib = W_b_ib(2);
        wz_b_ib = W_b_ib(3);

        %Calculem diverses matrius necessries per dur a terme els clculs.
        MatriuAcce = [0 -wz_b_ib*t wy_b_ib*t; wz_b_ib*t 0 -wx_b_ib*t;...
            -wy_b_ib*t wx_b_ib*t 0];   
        MatriuVelocitatTerra = [0 -w_ie 0; w_ie 0 0; 0 0 0];                                   
        Modul_Alfa = sqrt((wx_b_ib*t)^2 + (wy_b_ib*t)^2 + (wz_b_ib*t)^2);
        C_earth = [cos(w_ie*t) sin(w_ie*t) 0; -sin(w_ie*t) cos(w_ie*t)...
            0; 0 0 1];
        
        %Matriu rotaci, equacions optimitzaci
        if Modul_Alfa>1.E-8
            C_menys_mes = eye(3) + sin(Modul_Alfa)/Modul_Alfa*MatriuAcce...
                + (1 - cos(Modul_Alfa))/((Modul_Alfa)^2)...
                *MatriuAcce*MatriuAcce;
        else
            C_menys_mes = eye(3) + MatriuAcce;
        end
        
        C_ecef_b = C_earth*C_ecef_b_vella*C_menys_mes;
        
        %Fora especfica
        if Modul_Alfa>1.E-8
            C_ecef_b_ave = C_ecef_b_vella*(eye(3) + (1 - cos(Modul_Alfa))...
                /Modul_Alfa^2*MatriuAcce + (1 - sin(Modul_Alfa)...
                /Modul_Alfa)/Modul_Alfa^2*MatriuAcce*MatriuAcce)...
                - 0.5*MatriuAcce*C_ecef_b_vella;
        else
            C_ecef_b_ave = C_ecef_b_vella - 0.5*MatriuAcce*C_ecef_b_vella;
        end

        %Passem la fora especfica a ECEF frame.
        F_e_ib = C_ecef_b_ave*F_b_ib;
        
        %Calculem la gravetat en funci de la posici
        [G, gamma] = gravetat_ECEF(R_e_eb_vella(1), R_e_eb_vella(2),...
            R_e_eb_vella(3));                                                         

        %Clcul acceleraci:
        A_e_eb = F_e_ib + G - 2*MatriuVelocitatTerra*V_e_eb_vella;
        
        %Clcul velocitat
        V_e_eb = V_e_eb_vella + A_e_eb*t;
    
        %Clcul posici respecte ECEF
        R_e_eb = R_e_eb_vella + V_e_eb_vella*t + A_e_eb*(t^2)/2;
        
end

