function [G] = gravetatNED( L, h )
%Retorna la gravetat en el NED frame.
%Inputs:
%       L: coordenada de longitud de la posici on ens trobem (rad).
%       h: altura sobre el nivell del mar a que ens trobem. (m).
%Outputs:
%       G: Vector 3x1 amb les componenets Nord, Est i Down de la gravetat.
%       (m/s^2)

    Ro = 6378137; 
    Rp = 6356752.31425; 
    e = 0.0818191908425; 
    f = 1 / 298.257223563; 
    mu = 3.986004418E14; 
    w_ie = 7.292115E-5; 
    
    g0 = 9.7803253359*(1 + 0.001931853*(sin(L))^2)/sqrt(1 - e^2*(sin(L))^2);
    
    gN = -8.08E-9*h*sin(2*L);
    
    gD = g0*(1-2/Ro*(1 + f*(1 - 2*sin(L)^2) + (w_ie^2*Ro^2*Rp)/mu)*h + ...
        (3/Ro^2)*h^2);
    
    G = [gN; 0; gD];

end

