function [ anglePsi_nb, anglePsi_nb_graus ] = magneticHeading(matriuDades )
% Retorna l'orientaci yaw inicial segons la posici del Nord. La retorna
%amb radians i graus. Utilitza les dades de la matriuDades.
%Inputs:
%       matriuDades: matriu de dades recollides pels sensors de la IMU.
%Outputs:
%       anglePsi_nb: angle Psi (Yaw) en (rad).
%       anglePsi_nb_graus: angle Psi (Yaw) en (graus).

    %Declinaci magntica a la Bisbal d'Empord (0.583333 graus) o per ser 
    %exactes 32/60. S'ha buscat a internet. La passem a radiants.
    declinacio_magnetica = 32/60;
    declinacio_magnetica_rad = declinacio_magnetica*2*pi/360;
    
    %Per fer el magnetic Heading primer necessitem els valors de leveling.
    [angleFi_nb, angleTeta_nb, angleFi_nb_graus, angleTeta_nb_graus] = leveling(matriuDades );
    
    mbx_suma = 0;
    mby_suma = 0;
    mbz_suma = 0;
    
    %Fem la mitjana de les 20 primeres dades dels magnetmetres. D'aquesta 
    %manera corregim el possible soroll.
    for fila=1:1:20
        [mbx, mby, mbz] = llegirMagnetometre(fila, matriuDades);
        mbx_suma = mbx_suma + mbx;
        mby_suma = mby_suma + mby;
        mbz_suma = mbz_suma + mbz;
    end
    
    mbx_mitja = mbx_suma/20;
    mby_mitja = mby_suma/20;
    mbz_mitja = mbz_suma/20;
    
    %Apliquem les equacions del llibre per fer el magnetic Heading. El
    %calculem en radians i en graus.
    x = -mby_mitja*cos(angleFi_nb) + mbz_mitja*sin(angleFi_nb);
    y = mbx_mitja*cos(angleTeta_nb) + mby_mitja*sin(angleFi_nb)*sin(angleTeta_nb) + mbz_mitja*cos(angleFi_nb)*sin(angleTeta_nb);
    anglePsi_mb = atan2(x,y);
    
    %Fem la correcci de la declinaci magnetica per trobar el nord
    %geogrfic.
    anglePsi_nb = anglePsi_mb + declinacio_magnetica_rad;
    anglePsi_nb_graus = 360*anglePsi_nb/(2*pi);
   
end

