function [x_e_eb, y_e_eb, z_e_eb] = posicioNED_ECEF(L, lambda, h)
% Donada una posici de la Terra amb latitud(L),longitud (lambda) i altura
% (h)es retorna la posici segons el sistema ECEF amb coordenades
% cartesianes x, y, z.
%Inputs:
%       L: latitud (rad).
%       lambda: longitud (rad).
%       h: altura (m).
%Outputs:
%       x_e_eb,y_e_eb,z_e_eb: coordenades posici ECEF (m)

    R0 = 6378137;
    e = 0.081819191;
    
    Re = R0/(sqrt(1-e^2*sin(L)^2));
    
    x_e_eb = (Re + h)*cos(L)*cos(lambda);
    y_e_eb = (Re + h)*cos(L)*sin(lambda);
    z_e_eb = ((1 - e^2)*Re + h)*sin(L);

end

