%
%               PROGRAMA ECI
%
% Script que calcula la posici, velocitat, orientaci i acceleraci de la
% IMU segons el sistema de referncia ECI.

%               Inicialitzaci

clc;
clear all;
load('matlab.mat');

[indat] = data_loader('quiet2.csv');
matriuDades = indat;

%Transformar les dades dels giroscopis de graus/s a rad/s.
matriuDades(:,2:4)=matriuDades(:,2:4)*pi/180;

%Temps d'iteraci (s), velocitat rotaci Terra (rad/s).
t = 1/102.5;
w_ie = 7.292115e-5;

% Troba Roll i Pitch inicials de la IMU utilitzant la funcio LEVELING
[angleFi_nb, angleTeta_nb, angleFi_nb_graus, angleTeta_nb_graus] = leveling(matriuDades);  

%Troba Yaw de la  utilitzant la funcio MAGNETIC HEADING
[anglePsi_nb, anglePsi_nb_graus] = magneticHeading(matriuDades); 

%Posici segons parmetres de latitud, longitud i altitud.
L = input('Ingresa el valor de la latitud (L) inicial: ');            
lambda = input('Ingresa el valor de la longitud inicial: ');
h = input('Ingresa el valor de la altitud inicial: ');

L_rad = degtorad(L);
lambda_rad = degtorad(lambda);

%Troba posici respecte ECEF
[rx,ry,rz] = posicioNED_ECEF(L_rad, lambda_rad, h);                     
R_i_ib_vella = [rx; ry; rz];

%Crea matriu de rotaci de NED a Body frame, desprs de NED a ECI, i
%finalment, de Body a ECI.
[C_ned_b] = crearMatriuRotacioBody_NED( angleFi_nb, angleTeta_nb, anglePsi_nb);      
[C_eci_ned] = crearMatriuRotacioNED_ECI( L, lambda, t_acumulat);                                 
C_eci_b_vella = C_eci_ned*C_ned_b;                                                           

%Velocitat inicial respecte ECEF
V_e_eb = [0; 0; 0];

%Velocitat inicial respecte ECI                                          
[V_i_ib_vella] = velocitatInicialECI( R_i_ib_vella, V_e_eb );                                           

%Creem fitxer de dades
fileID = fopen('resultatsProvaQuiet_ECI.txt','w');             
fprintf(fileID,'\n%s %s %s\n\n','rx','ry','rz');
fprintf(fileID,'%f      %f      %f\n', R_i_ib_vella);

%Creem fitxer de dades
fileID2 = fopen('resultatsProvaQuiet_ECIenCoordenadesECEF.txt','w');             
fprintf(fileID2,'\n%s %s %s\n\n','rx','ry','rz');
fprintf(fileID2,'%f      %f      %f\n', R_i_ib_vella);

%Creem fitxer de dades per l'orientaci
fileID3 = fopen('resultatsProvaQuiet_ECI_orientacio.txt','w');             
fprintf(fileID3,'\n%s %s %s\n\n','Roll','Pitch','Yaw');
fprintf(fileID3,'%f      %f      %f\n', angleFi_nb_graus, angleTeta_nb_graus,anglePsi_nb_graus); 

%**********ITERACI***********

%Ens dona el nombre de files (n) i columnes (c) de la matriu de dades de la IMU.
[n, c] = size(matriuDades); 

for fila=1:1:n,
       
    %Llegir velocitat angular del fitxer de dades.
    [wx_b_ib, wy_b_ib, wz_b_ib] = llegirW(fila, matriuDades);
    W_b_ib = [wx_b_ib; wy_b_ib; wz_b_ib];
    
    %Llegim la fora especfica del fitxer de dades    
    [fx_b_ib, fy_b_ib, fz_b_ib] = llegirForcaEspecifica(fila,matriuDades);                  
    F_b_ib = [fx_b_ib; fy_b_ib; fz_b_ib]*9.80655; 
    
    %   EQUACIONS DE NAVEGACIO ECI
    %Apliquem les equacions de navegaci per trobar la posici, la
    %velocitat i la matriu de rotacio.
    [R_i_ib, V_i_ib, C_eci_b ] = equacionsNavegacioECI( t, R_i_ib_vella, V_i_ib_vella, C_eci_b_vella, F_b_ib, W_b_ib );
    
    
    fprintf(fileID,'%f      %f    %f\n', R_i_ib);
    
    
    %Fitxer en coordenades ECEF.
    [C_ecef_eci] = crearMatriuECI_ECEF(t_acumulat);
    R_e_eb = C_ecef_eci*R_i_ib;
    fprintf(fileID2,'%f      %f    %f\n', R_e_eb);
    
    PosicioECIambECEF(fila, 1) = R_e_eb(1,1)- 4743050.930637;
    PosicioECIambECEF(fila, 2) = R_e_eb(2,1)- 252319.376959;
    PosicioECIambECEF(fila, 3) = R_e_eb(3,1)- 4242591.914783;
    
    
    %Fitxer angles Euler.
    [L, lambda, h] = Borkowski(R_e_eb(1), R_e_eb(2), R_e_eb(3));
    [ C_n_i ] = crearMatriuECI_NED( t_acumulat, L, lambda );
     C_n_b = C_n_i*C_eci_b;
    [Roll, Pitch, Yaw] = calcularAnglesEuler( C_n_b );
    
    fprintf(fileID3,'%f      %f    %f\n', Roll, Pitch, Yaw);
    
    R_i_ib_vella = R_i_ib;
    V_i_ib_vella = V_i_ib;
    C_eci_b_vella = C_eci_b;
    
end


fclose(fileID);
fclose(fileID2);
fclose(fileID3);