function [V_i_ib] = velocitatInicialECI( R_i_ib, V_e_eb )
%Troba la velocitat inicial respecte ECI segons el punt de la Terra on es
%troba. ATENCI: Aquesta funci noms serveix per l'instant incial, ja que
%               suposem que en aquest moment ECI i ECEF estan alineats. Si 
%               volssim que servis per qualsevol instant hauriem de 
%               calcular la matriu C_eci_ecef segons el temps.
%Inputs:
%       R_i_ib: posici respecte ECI (m)
%       V_e_eb: velocitat inicial respecte ECEF (m/s)
%Outputs:
%       V_i_ib: velocitat inicial respecte ECI. (m/s)
    
    w_ie = 7.292115e-5; 
    Matriu_e_ie = [0 -w_ie 0; w_ie 0 0; 0 0 0];
    C_eci_ecef = [1 0 0; 0 1 0; 0 0 1];
    
    V_i_ib = C_eci_ecef*(V_e_eb + Matriu_e_ie*R_i_ib);

end

